@@ -96,8 +96,8 @@ EmbossTool::EmbossTool(TQObject* parent)
 
     // -------------------------------------------------------------
 
-    connect(m_depthInput, TQT_SIGNAL(valueChanged (int)),
-            this, TQT_SLOT(slotTimer()));
+    connect(m_depthInput, TQ_SIGNAL(valueChanged (int)),
+            this, TQ_SLOT(slotTimer()));
 }
 
 EmbossTool::~EmbossTool()
