@@ -33,7 +33,7 @@ class TDEAction;
 
 class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_RainDrop : public Digikam::ImagePlugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
