@@ -96,11 +96,11 @@ JP2KSettings::JP2KSettings(TQWidget *parent)
     d->JPEG2000Grid->addMultiCellWidget(d->JPEG2000compression, 1, 1, 1, 1);
     d->JPEG2000Grid->setColStretch(1, 10);
 
-    connect(d->JPEG2000LossLess, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotToggleJPEG2000LossLess(bool)));
+    connect(d->JPEG2000LossLess, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotToggleJPEG2000LossLess(bool)));
 
-    connect(d->JPEG2000LossLess, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotToggleJPEG2000LossLess(bool)));
+    connect(d->JPEG2000LossLess, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotToggleJPEG2000LossLess(bool)));
 }
 
 JP2KSettings::~JP2KSettings()
