@@ -41,7 +41,7 @@ class EditorStackViewPriv;
 
 class DIGIKAM_EXPORT EditorStackView : public TQWidgetStack
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
